@@ -55,12 +55,15 @@ def sign(message, ssldir, certname, **config):
     """
 
     certificate = M2Crypto.X509.load_cert(
-        "%s/certs/%s.pem" % (ssldir, certname)).as_pem()
+        "%s/%s.crt" % (ssldir, certname)).as_pem()
     # FIXME ? -- Opening this file requires elevated privileges in stg/prod.
     rsa_private = M2Crypto.RSA.load_key(
-        "%s/private_keys/%s.pem" % (ssldir, certname))
+        "%s/%s.key" % (ssldir, certname))
 
-    signature = rsa_private.sign_rsassa_pss(fedmsg.json.dumps(message))
+    digest = M2Crypto.EVP.MessageDigest('sha1')
+    digest.update(fedmsg.json.dumps(message))
+
+    signature = rsa_private.sign(digest.digest())
 
     # Return a new dict containing the pairs in the original message as well
     # as the new authn fields.
@@ -110,15 +113,20 @@ def validate(message, ssldir, **config):
     #   https://bugzilla.osafoundation.org/show_bug.cgi?id=11690
     # FIXME -- the CRL is not actually checked here.
     ctx = m2ext.SSL.Context()
-    ctx.load_verify_locations(cafile="%s/certs/ca.pem" % ssldir)
+    ctx.load_verify_locations(cafile="%s/ca.crt" % ssldir)
     if not ctx.validate_certificate(cert):
         return fail("X509 certificate is not valid.")
 
     # If the cert is good, then test to see if the signature in the messages
     # matches up with the provided cert.
     rsa_public = cert.get_pubkey().get_rsa()
-    if not rsa_public.verify_rsassa_pss(fedmsg.json.dumps(message), signature):
-        return fail("RSA signature failed to validate.")
+    digest = M2Crypto.EVP.MessageDigest('sha1')
+    digest.update(fedmsg.json.dumps(message))
+    try:
+        if not rsa_public.verify(digest.digest(), signature):
+            raise M2Crypto.RSA.RSAError("RSA signature failed to validate.")
+    except M2Crypto.RSA.RSAError as e:
+        return fail(str(e))
 
     return True
 
